@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2016 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2017 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -56,7 +56,7 @@ class NextPopover(Gtk.Popover):
             del art
             self.__cover.set_tooltip_text(Lp().player.next_track.album.name)
             self.__cover.show()
-            queue = Lp().player.get_queue()
+            queue = Lp().player.queue
             if queue and queue[0] == Lp().player.next_track.id:
                 self.__skip_btn.hide()
             else:
